"""
Mobile MCP Server Package
"""
# 🎯 移除导入以避免 RuntimeWarning
# 当使用 python -m mobile_mcp.mcp.mcp_server 运行时，
# 不应该在 __init__.py 中预先导入 mcp_server
# from .mcp_server import MobileMCPServer

__all__ = []


